.. _reference-index:

#################################
  The Grok Reference
#################################
(keep this under your pillow)

:Reference for Grok version: |version|
:Document last updated: |today|
    
This is the Grok reference documentation. It is organized by the Python
artefacts that implement it's concepts.

.. toctree::
   :maxdepth: 2

   components.rst
   directives.rst
   decorators.rst
   functions.rst
   events.rst
   exceptions.rst
   testing.rst
